@@ -6,21 +6,30 @@ import fs from 'fs/promises';
 import path from 'path';
 import os from 'os';
 import { config } from 'dotenv';
+import { getVarVal } from '../configuration.js';
 
 // 환경 변수 로드
 config({ path: path.join(process.cwd(), '.env') });
 
-// PostgreSQL 연결 설정
-const dbPool = new Pool({
-  host: process.env.DB_HOST || process.env.POSTGRES_HOST || 'localhost',
-  port: process.env.DB_PORT || process.env.POSTGRES_PORT || 5433,
-  user: process.env.DB_USER || process.env.POSTGRES_USER || 'ivs',
-  password: process.env.DB_PASSWORD || process.env.POSTGRES_PASSWORD || '1234',
-  database: process.env.DB_NAME || process.env.POSTGRES_DB || 'airun',
-  max: 10,
-  idleTimeoutMillis: 30000,
-  connectionTimeoutMillis: 10000,
-});
+// PostgreSQL 연결 설정 (중앙화된 설정 사용)
+async function createDatabasePool() {
+  const dbHost = await getVarVal('DB_HOST') || 'localhost';
+  const dbPort = await getVarVal('DB_PORT') || 5433;
+  const dbUser = await getVarVal('DB_USER') || 'ivs';
+  const dbPassword = await getVarVal('DB_PASSWORD') || '1234';
+  const dbName = await getVarVal('DB_NAME') || 'airun';
+  
+  return new Pool({
+    host: dbHost,
+    port: dbPort,
+    user: dbUser,
+    password: dbPassword,
+    database: dbName,
+    max: 10,
+    idleTimeoutMillis: 30000,
+    connectionTimeoutMillis: 10000,
+  });
+}
 
 // 공공데이터포털 API 키
 const PUBLIC_DATA_API_KEY = '156a84b10f1664ffa60f7c9836badf761fc72eaacb24130ed433c569a5bf9b89';
@@ -43,7 +52,7 @@ const writeLog = async (message) => {
 };
 
 // 데이터베이스 헬퍼 함수
-async function insertDataCollectionLog(source, collectionType, totalItems, newItems, updatedItems, failedItems, startTime, endTime, status, errorMessage = null, details = {}) {
+async function insertDataCollectionLog(dbPool, source, collectionType, totalItems, newItems, updatedItems, failedItems, startTime, endTime, status, errorMessage = null, details = {}) {
   const duration = Math.floor((endTime - startTime) / 1000);
   
   const query = `
@@ -68,7 +77,7 @@ async function insertDataCollectionLog(source, collectionType, totalItems, newIt
   }
 }
 
-async function upsertBusinessAnnouncement(data) {
+async function upsertBusinessAnnouncement(dbPool, data) {
   const query = `
     INSERT INTO business_announcements (
       id, source, external_id, title, description, category, subcategory,
@@ -334,7 +343,7 @@ function parsePPSData(item) {
 }
 
 // 각 API 수집 함수들
-async function collectKStartupData() {
+async function collectKStartupData(dbPool) {
   const source = 'KSTARTUP';
   const startTime = new Date();
   let totalItems = 0, newItems = 0, updatedItems = 0, failedItems = 0;
@@ -358,7 +367,7 @@ async function collectKStartupData() {
       for (const item of data.data) {
         try {
           const parsedData = parseKStartupData(item);
-          const wasInserted = await upsertBusinessAnnouncement(parsedData);
+          const wasInserted = await upsertBusinessAnnouncement(dbPool, parsedData);
           
           if (wasInserted) {
             newItems++;
@@ -373,19 +382,19 @@ async function collectKStartupData() {
     }
 
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
     await writeLog(`${source} 수집 완료: 총 ${totalItems}개, 신규 ${newItems}개, 업데이트 ${updatedItems}개, 실패 ${failedItems}개`);
     
     return { success: true, totalItems, newItems, updatedItems, failedItems };
   } catch (error) {
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
     await writeLog(`${source} 수집 실패: ${error.message}`);
     return { success: false, error: error.message };
   }
 }
 
-async function collectMSITData() {
+async function collectMSITData(dbPool) {
   const source = 'MSIT';
   const startTime = new Date();
   let totalItems = 0, newItems = 0, updatedItems = 0, failedItems = 0;
@@ -410,7 +419,7 @@ async function collectMSITData() {
         try {
           const item = itemWrapper.item;
           const parsedData = parseMSITData(item);
-          const wasInserted = await upsertBusinessAnnouncement(parsedData);
+          const wasInserted = await upsertBusinessAnnouncement(dbPool, parsedData);
           
           if (wasInserted) {
             newItems++;
@@ -425,19 +434,19 @@ async function collectMSITData() {
     }
 
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
     await writeLog(`${source} 수집 완료: 총 ${totalItems}개, 신규 ${newItems}개, 업데이트 ${updatedItems}개, 실패 ${failedItems}개`);
     
     return { success: true, totalItems, newItems, updatedItems, failedItems };
   } catch (error) {
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
     await writeLog(`${source} 수집 실패: ${error.message}`);
     return { success: false, error: error.message };
   }
 }
 
-async function collectSMEData() {
+async function collectSMEData(dbPool) {
   const source = 'SME';
   const startTime = new Date();
   let totalItems = 0, newItems = 0, updatedItems = 0, failedItems = 0;
@@ -466,7 +475,7 @@ async function collectSMEData() {
       for (const item of itemList) {
         try {
           const parsedData = parseSMEData(item);
-          const wasInserted = await upsertBusinessAnnouncement(parsedData);
+          const wasInserted = await upsertBusinessAnnouncement(dbPool, parsedData);
           
           if (wasInserted) {
             newItems++;
@@ -481,19 +490,19 @@ async function collectSMEData() {
     }
 
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
     await writeLog(`${source} 수집 완료: 총 ${totalItems}개, 신규 ${newItems}개, 업데이트 ${updatedItems}개, 실패 ${failedItems}개`);
     
     return { success: true, totalItems, newItems, updatedItems, failedItems };
   } catch (error) {
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
     await writeLog(`${source} 수집 실패: ${error.message}`);
     return { success: false, error: error.message };
   }
 }
 
-async function collectPPSData() {
+async function collectPPSData(dbPool) {
   const source = 'PPS';
   const startTime = new Date();
   let totalItems = 0, newItems = 0, updatedItems = 0, failedItems = 0;
@@ -525,7 +534,7 @@ async function collectPPSData() {
       for (const item of items) {
         try {
           const parsedData = parsePPSData(item);
-          const wasInserted = await upsertBusinessAnnouncement(parsedData);
+          const wasInserted = await upsertBusinessAnnouncement(dbPool, parsedData);
           
           if (wasInserted) {
             newItems++;
@@ -540,20 +549,20 @@ async function collectPPSData() {
     }
 
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'success');
     await writeLog(`${source} 수집 완료: 총 ${totalItems}개, 신규 ${newItems}개, 업데이트 ${updatedItems}개, 실패 ${failedItems}개`);
     
     return { success: true, totalItems, newItems, updatedItems, failedItems };
   } catch (error) {
     const endTime = new Date();
-    await insertDataCollectionLog(source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
+    await insertDataCollectionLog(dbPool, source, 'api', totalItems, newItems, updatedItems, failedItems, startTime, endTime, 'failed', error.message);
     await writeLog(`${source} 수집 실패: ${error.message}`);
     return { success: false, error: error.message };
   }
 }
 
 // 메인 수집 함수
-async function runDailyCollection() {
+async function runDailyCollection(dbPool) {
   await writeLog('========================================');
   await writeLog('매일 사업공고 데이터 수집 시작');
   await writeLog('========================================');
@@ -576,7 +585,7 @@ async function runDailyCollection() {
 
   // 1. K-Startup 수집
   await writeLog('1/4 K-Startup 데이터 수집...');
-  results.kstartup = await collectKStartupData();
+  results.kstartup = await collectKStartupData(dbPool);
   if (results.kstartup.success) {
     results.summary.successful_sources++;
     results.summary.total_items += results.kstartup.totalItems;
@@ -590,7 +599,7 @@ async function runDailyCollection() {
 
   // 2. MSIT 수집
   await writeLog('2/4 과학기술정보통신부 데이터 수집...');
-  results.msit = await collectMSITData();
+  results.msit = await collectMSITData(dbPool);
   if (results.msit.success) {
     results.summary.successful_sources++;
     results.summary.total_items += results.msit.totalItems;
@@ -603,7 +612,7 @@ async function runDailyCollection() {
 
   // 3. SME 수집
   await writeLog('3/4 중소벤처기업부 데이터 수집...');
-  results.sme = await collectSMEData();
+  results.sme = await collectSMEData(dbPool);
   if (results.sme.success) {
     results.summary.successful_sources++;
     results.summary.total_items += results.sme.totalItems;
@@ -616,7 +625,7 @@ async function runDailyCollection() {
 
   // 4. PPS 수집
   await writeLog('4/4 조달청 데이터 수집...');
-  results.pps = await collectPPSData();
+  results.pps = await collectPPSData(dbPool);
   if (results.pps.success) {
     results.summary.successful_sources++;
     results.summary.total_items += results.pps.totalItems;
@@ -644,8 +653,12 @@ async function runDailyCollection() {
 
 // 메인 실행
 (async () => {
+  let dbPool;
   try {
-    const results = await runDailyCollection();
+    // 중앙화된 설정으로 데이터베이스 풀 생성
+    dbPool = await createDatabasePool();
+    
+    const results = await runDailyCollection(dbPool);
     
     // 정상 종료 코드 (성공한 소스가 있으면 0, 모두 실패하면 1)
     const exitCode = results.summary.successful_sources > 0 ? 0 : 1;
@@ -654,7 +667,9 @@ async function runDailyCollection() {
     process.exit(exitCode);
   } catch (error) {
     await writeLog(`치명적 오류 발생: ${error.message}`);
-    await dbPool.end();
+    if (dbPool) {
+      await dbPool.end();
+    }
     process.exit(1);
   }
 })();
\ No newline at end of file
